Import and Update — SCIA - Single Case Intervention Analysis with Python

Skip to main content
`Ctrl`+`K`

# Import and Update

before creating a `dataframe` you need to import package in you favorite term. usually I like to import as `sc`, to do so:

    import scia as sc

    📖 scia 1.101.0.dev6 - For Documentation, visit: https://ahsankhodami.github.io/scia/intro.html

as you can see, the package shows its current `version` which at the currennt time is `1.100.31` which I used for this tutorial crafting, but you can always check the PyPi package index or upgrade it using following command

    pip install --upgrade scia

Now that you have imported package you can continue with other functions.